<?php if ( !defined( 'ABSPATH' ) ) exit();

/**
 * Returns every date between two dates as an array
 * @param string $startDate the start of the date range
 * @param string $endDate the end of the date range
 * @param string $format DateTime format, default is Y-m-d
 * @return array returns every date between $startDate and $endDate, formatted as "Y-m-d"
 */


function ovacrs_createDatefull($start, $end, $format = "Y-m-d"){
    
    $dates = array();
    while($start <= $end){
        array_push( $dates, date( $format, $start) );
        $start += 86400;
    }

    return $dates;
} 

function total_between_2_days( $start, $end){
    return floor( abs( strtotime($end) - strtotime($start) ) / (60*60*24) );
}




function ovacrs_array_flatten($array) { 
  if (!is_array($array)) { 
    return FALSE; 
  } 
  $result = array(); 
  foreach ($array as $key => $value) { 
    if (is_array($value)) { 
      $result = array_merge($result, ovacrs_array_flatten($value)); 
    } 
    else { 
      $result[$key] = $value; 
    } 
  } 
  return $result; 
}



function get_order_rent_time( $product_id, $order_status = array( 'wc-completed' ) ){


    global $wpdb;

    $order_date = $order_date_bg = $dates_avaiable = array();
    $total_each_day = $orders_ids = array();

    $count_car_in_store = get_post_meta( $product_id, 'ovacrs_car_count', true );

    if( is_array( $product_id ) ){

       foreach ($product_id as $key => $value) {

           $orders_id = $wpdb->get_col("
                SELECT Distinct order_items.order_id
                FROM {$wpdb->prefix}woocommerce_order_items as order_items
                LEFT JOIN {$wpdb->prefix}woocommerce_order_itemmeta as order_item_meta ON order_items.order_item_id = order_item_meta.order_item_id
                LEFT JOIN {$wpdb->posts} AS posts ON order_items.order_id = posts.ID
                WHERE posts.post_type = 'shop_order'
                AND posts.post_status IN ( '" . implode( "','", $order_status ) . "' )
                AND order_items.order_item_type = 'line_item'
                AND order_item_meta.meta_key = '_product_id'
                AND order_item_meta.meta_value = '$value'
            ");

           $orders_ids = array_merge( $orders_ids, $orders_id );

       }

    }else{

        
        $orders_ids = $wpdb->get_col("
            SELECT Distinct order_items.order_id
            FROM {$wpdb->prefix}woocommerce_order_items as order_items
            LEFT JOIN {$wpdb->prefix}woocommerce_order_itemmeta as order_item_meta ON order_items.order_item_id = order_item_meta.order_item_id
            LEFT JOIN {$wpdb->posts} AS posts ON order_items.order_id = posts.ID
            WHERE posts.post_type = 'shop_order'
            AND posts.post_status IN ( '" . implode( "','", $order_status ) . "' )
            AND order_items.order_item_type = 'line_item'
            AND order_item_meta.meta_key = '_product_id'
            AND order_item_meta.meta_value = '$product_id'
        ");    
    }

    


    foreach ($orders_ids as $key => $value) {

        // Get Order Detail by Order ID
        $order = wc_get_order($value);

        // Get Meta Data type line_item of Order
        $order_line_items = $order->get_items( apply_filters( 'woocommerce_purchase_order_item_types', 'line_item' ) );
       
        // For Meta Data
        foreach ( $order_line_items as $item_id => $item ) {

            $ovacrs_check_in_store = $ovacrs_check_out_store = '';

            // Get value of check-in, check-out
            foreach ( $item->get_formatted_meta_data() as $meta_id => $meta ) {
                if( $meta->key == 'room_check_in' ){
                    $ovacrs_check_in_store = strtotime( str_replace('/', '-', $meta->value) );
                }
                if( $meta->key == 'room_check_out' ){
                    $ovacrs_check_out_store = strtotime( str_replace('/', '-', $meta->value) );
                }
                if( $meta->key == 'room_rooms' ){
                    $room_rooms = $meta->value;
                }
            }


            // For each total Rooms to calculate total day
            if( $room_rooms > 0 ){ for ($i = 0; $i < $room_rooms; $i++) {
            
                if( $ovacrs_check_out_store >= current_time( 'timestamp' ) ){ 


                    $start_date = date( 'Y-m-d', $ovacrs_check_in_store );
                    $end_date = date( 'Y-m-d', $ovacrs_check_out_store );

                    $total_between_2_days = total_between_2_days( $start_date, $end_date );



                    if( $total_between_2_days == 0 ){ // In a day

                        $item =  array(  'start' => date( 'Y-m-d', $ovacrs_check_in_store ),
                                 'end' => date( 'Y-m-d', $ovacrs_check_out_store ),
                                 'title' => date_i18n( 'H:i', $ovacrs_check_in_store ).'-'.date_i18n( 'H:i', $ovacrs_check_out_store )
                         );
                        array_push( $dates_avaiable, $item );
                        array_push( $total_each_day, date( 'Y-m-d', $ovacrs_check_in_store )  );

                    }else if( $total_between_2_days == 1 ) { // 2 day beside

                        $item =  array(  'start' => date( 'Y-m-d', $ovacrs_check_in_store ),
                                 'end' => date( 'Y-m-d', $ovacrs_check_in_store ),
                                 'title' => date_i18n( 'H:i', $ovacrs_check_in_store ).esc_html__(' 24:00', 'ova-hotel')
                         );
                        array_push( $dates_avaiable, $item );
                        array_push( $total_each_day, date( 'Y-m-d', $ovacrs_check_in_store )  );

                    }else{ // from 3 days 

                        $item =  array(  'start' => date( 'Y-m-d', $ovacrs_check_in_store ),
                                 'end' => date( 'Y-m-d', $ovacrs_check_in_store ),
                                 'title' => date_i18n( 'H:i', $ovacrs_check_in_store ).esc_html__(' 24:00', 'ova-hotel')
                         );
                        array_push( $dates_avaiable, $item );

                        array_push( $total_each_day, date( 'Y-m-d', $ovacrs_check_in_store )  );
                        


                        $date_between_start_end = ovacrs_createDatefull( strtotime( $start_date ), strtotime( $end_date ), $format='Y-m-d' );

                        // Remove first and last array
                        array_shift( $date_between_start_end ); 
                        array_pop( $date_between_start_end );

                        foreach ( $date_between_start_end as $key => $value) {

                            $item =  array(  'start' => $value,
                                     'end' => $value,
                                     'title' => esc_html__('00:00 24:00 ', 'ova-hotel')
                             );
                            array_push( $dates_avaiable, $item );

                            array_push( $total_each_day, $value  );
                        }

                    }

                }
            } }
            
        }
    }

    // Check Unavaiable Time in Product
    $ovacrs_untime_startdate = get_post_meta( $product_id[0], 'ovacrs_untime_startdate', true );
    $ovacrs_untime_enddate   = get_post_meta( $product_id[0], 'ovacrs_untime_enddate', true );

    if( is_array( $ovacrs_untime_startdate ) && !empty( $ovacrs_untime_startdate ) && !empty( $ovacrs_untime_enddate ) ){
        foreach ($ovacrs_untime_startdate as $key => $value) {

            // Convert date_formar 'd/m/Y' to 'd-m-Y'
            $untime_startdate   = ovacrs_create_from_format( $ovacrs_untime_startdate[$key] );
            $untime_enddate     = ovacrs_create_from_format( $ovacrs_untime_enddate[$key] );

            if ( !empty( $ovacrs_untime_startdate[$key] ) && !empty( $ovacrs_untime_enddate[$key] ) ) {
                $push_date_unavailable_untime = ovacrs_createDatefull( strtotime( $untime_startdate ), strtotime( $untime_enddate ), $format='Y-m-d' );

                foreach ( $push_date_unavailable_untime as $key => $value_untime) {
                    $item_untime =  array(  'start' => $value,
                             'end' => $value_untime,
                             'title' => esc_html__('00:00 24:00 ', 'ova-hotel')
                     );
                    array_push( $dates_avaiable, $item_untime );

                    array_push( $total_each_day, $value_untime  );
                }
            }
        }
    }

    $order_date_bg = ovacrs_array_flatten( $total_each_day );
    $count_values = array_count_values( $order_date_bg );

    $date_booked = array();
    $bg_rented = get_theme_mod( 'primary_color', '#b9a271' );
    foreach ($count_values as $key => $value) {
        if( $value >= $count_car_in_store ){
            $item =  array(  'start' => $key,
                             'end' => $key,
                             'rendering' => 'background',
                             'color' => $bg_rented,
                             'overlap' => false,
                             'title' => '',
                             
                     );
            array_push( $date_booked, $item );
        }
    }

    return json_encode( $date_booked );

}




function ovacrs_get_orders_by_product_id( $product_id, $order_status = array( 'wc-completed' ) ){
    global $wpdb;

    $orders_ids = array();

     if( is_array( $product_id ) ){

       foreach ($product_id as $key => $value) {

           $orders_id = $wpdb->get_col("
                SELECT  order_items.order_id
                FROM {$wpdb->prefix}woocommerce_order_items as order_items
                LEFT JOIN {$wpdb->prefix}woocommerce_order_itemmeta as order_item_meta ON order_items.order_item_id = order_item_meta.order_item_id
                LEFT JOIN {$wpdb->posts} AS posts ON order_items.order_id = posts.ID
                WHERE posts.post_type = 'shop_order'
                AND posts.post_status IN ( '" . implode( "','", $order_status ) . "' )
                AND order_items.order_item_type = 'line_item'
                AND order_item_meta.meta_key = '_product_id'
                AND order_item_meta.meta_value = '$value'
            ");

           $orders_ids = array_merge_recursive( $orders_ids, $orders_id );

       }

    }else{

        
        $orders_ids = $wpdb->get_col("
            SELECT   order_items.order_id
            FROM {$wpdb->prefix}woocommerce_order_items as order_items
            LEFT JOIN {$wpdb->prefix}woocommerce_order_itemmeta as order_item_meta ON order_items.order_item_id = order_item_meta.order_item_id
            LEFT JOIN {$wpdb->posts} AS posts ON order_items.order_id = posts.ID
            WHERE posts.post_type = 'shop_order'
            AND posts.post_status IN ( '" . implode( "','", $order_status ) . "' )
            AND order_items.order_item_type = 'line_item'
            AND order_item_meta.meta_key = '_product_id'
            AND order_item_meta.meta_value = '$product_id'
        ");    
    }

    return array_unique( $orders_ids );
}


// Search Room
function ovacrs_search_rooms( $data_search ){

    
    $room_check_in = isset( $data_search['room_check_in'] )  ? strtotime( $data_search['room_check_in'] ) : '';
    $room_check_out = isset( $data_search['room_check_out'] ) ? strtotime( $data_search['room_check_out'] ) : '';
    $room_adults = isset( $data_search['room_adults'] )  ? ( $data_search['room_adults'] ) : 0;
    $room_childrens = isset( $data_search['room_childrens'] )  ? ( $data_search['room_childrens'] ) : 0;
    $room_rooms = isset( $data_search['room_rooms'] )  ? ( $data_search['room_rooms'] ) : 0;

    

    $statuses = array( 'wc-completed', 'wc-processing', 'wc-on-hold' );

    $args_base = $args_adults = $args_childrens = $args_rooms = $error = array();

    $items_id = array();

    $args_base = array(
        'post_type' => 'product',
        'posts_per_page' => '-1',
        'post_status' => 'publish'
    );

    if( $room_adults > 0 ){
       $args_adults = array(
            'meta_query' => array(
                array(
                    'key' => 'ovacrs_car_max_adults',
                    'value' => $room_adults,
                    'compare' => '>='
                )
            )
        );

    }

    if( $room_childrens > 0 ){
       $args_childrens = array(
            'meta_query' => array(
                array(
                    'key' => 'ovacrs_car_max_childrens',
                    'value' => $room_childrens,
                    'compare' => '>='
                )
            )
        );

    }


    if( $room_rooms > 0 ){
        $args_rooms = array(
            'meta_query' => array(
                array(
                    'key' => 'ovacrs_car_count',
                    'value' => $room_rooms,
                    'compare' => '>='
                )
            )
        );
    }
   

    $args = array_merge_recursive( $args_base, $args_adults, $args_childrens, $args_rooms );

    // Get All products
    $items = new WP_Query( $args );

    if ( $items->have_posts() ) : while ( $items->have_posts() ) : $items->the_post();
        
        $id = get_the_id();

        $room_using_this_time = 0;

        // Check Product Untime
        $product_untime_flag = true;
        $product_untime_startdate   = get_post_meta( $id, 'ovacrs_untime_startdate', true );
        $product_untime_enddate     = get_post_meta( $id, 'ovacrs_untime_enddate', true );

        if( $product_untime_startdate && $product_untime_enddate ){
            foreach ($product_untime_startdate as $key => $value) {

                // Check if Time Rent is in Untime
                if( ! ( $room_check_out < strtotime( $product_untime_startdate[$key] ) || strtotime( $product_untime_enddate[$key] ) < $room_check_in ) ){
                    $product_untime_flag = false;
                    break;
                }

            }
        }

        if ( $product_untime_flag ):

            $room_check_in_store = $room_check_out_store = '';

            // Total Car in the Store
            $total_rooms_store = get_post_meta( $id, 'ovacrs_car_count', true ) ? get_post_meta( $id, 'ovacrs_car_count', true ) : 0;
            
            // Get array product_ids for case use WPML
            $translated_ids = get_arr_product_ids( $id );

            $orders_ids = ovacrs_get_orders_by_product_id( $translated_ids, $statuses );

            // For Order ID
            foreach ($orders_ids as $key => $value) {

                // Get Order Detail by Order ID
                $order = wc_get_order($value);

                // Get Meta Data type line_item of Order
                $order_items = $order->get_items( apply_filters( 'woocommerce_purchase_order_item_types', 'line_item' ) );
               
                // For Meta Data
                foreach ( $order_items as $item_id => $item ) {

                    // Check Line Item have item ID is Car_ID
                    if( in_array( $item->get_product_id(), $translated_ids ) ){

                        // Get value of pickup date, pickoff date
                        foreach ( $item->get_formatted_meta_data() as $meta_id => $meta ) {
                            if( $meta->key == 'room_check_in' ){
                                $room_check_in_store = strtotime( str_replace('/', '-', $meta->value) );
                            }
                            if( $meta->key == 'room_check_out' ){
                                $room_check_out_store = strtotime( str_replace('/', '-', $meta->value) ) - 24*60*60;
                            }
                        }

                        // Only compare date when "PickOff Date in Store" > "Current Time" becaue "PickOff Date Rent" have to > "Current Time"
                        if( $room_check_out_store >= current_time( 'timestamp' ) ){
                            
                            // Check rent time
                            if( ! ($room_check_out - 24*60*60 < $room_check_in_store || $room_check_out_store < $room_check_in ) ){
                                $room_using_this_time++;
                            }

                        }
                        
                    }

                }

            }

            if( $room_using_this_time < $total_rooms_store ){
                array_push($items_id, $id);
            }
        endif;

    endwhile; else :
        return $items_id;
    endif; 

    if( $items_id ){
        
        $paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;

        $args_product = array(
            'post_type' => 'product',
            'posts_per_page' => get_theme_mod( 'rooms_result_page', '6' ),
            'paged' => $paged,
            'post_status' => 'publish',
            'post__in' => $items_id
        );

        $rooms_available = new WP_Query( $args_product );
        return $rooms_available;

    }

    wp_reset_postdata();

    return false;


}




// Check Rent by Day or Hour or both
function ovacrs_get_price_type( $post_id ){
    return get_post_meta( $post_id, 'ovacrs_price_type', true ) ;
}

// Get value rent day
function ovacrs_get_price_day( $post_id ){
    return wc_price( get_post_meta( $post_id, '_regular_price', true ) );
}

// Get value hour day
function ovacrs_get_price_hour( $post_id ){
    return wc_price( get_post_meta( $post_id, 'ovacrs_regul_price_hour', true ) );
}



// Get all location
function ovacrs_get_locations(){
    $locations = new WP_Query(
        array(
            'post_type' => 'location',
            'post_stat' => 'publish',
            'posts_per_page' => '-1'
        )
    );

    return $locations;

}

function ovacrs_get_locations_html( $name = '', $required = 'required', $selected = '' ){
    $locations = new WP_Query(
        array(
            'post_type' => 'location',
            'post_stat' => 'publish',
            'posts_per_page' => '-1'
        )
    );

    $html = '<select name="'.$name.'" class="'.$required.'">
        <option value="">'. esc_html__('Select Location', 'ova-hotel').'</option>';
        if($locations->have_posts() ) : while ( $locations->have_posts() ) : $locations->the_post();
            $active = ( trim( get_the_title() ) === trim( $selected ) ) ? 'selected="selected"' : '';
            $html .= '<option value="'.get_the_title().'" '.$active.'>'.get_the_title().'</option>';
        endwhile; endif;wp_reset_postdata();
    $html .= '</select>';

    return $html;


}







/* Select html Category Rental */
function ovacrs_cat_rental( $selected, $required, $exclude_id ){
    $args = array(
        'show_option_all'    => '',
        'show_option_none'   => esc_html__( 'All Categories', 'ova-hotel' ),
        'option_none_value'  => '',
        'orderby'            => 'ID',
        'order'              => 'ASC',
        'show_count'         => 0,
        'hide_empty'         => 0,
        'child_of'           => 0,
        'exclude'            => $exclude_id,
        'include'            => '',
        'echo'               => 0,
        'selected'           => $selected,
        'hierarchical'       => 1,
        'name'               => 'cat',
        'id'                 => '',
        'class'              => 'postform '.$required,
        'depth'              => 0,
        'tab_index'          => 0,
        'taxonomy'           => 'product_cat',
        'hide_if_empty'      => false,
        'value_field'        => 'slug',
    );
   
   return wp_dropdown_categories($args);
}


function ovacrs_type_rental( $selected, $required, $exclude_id ){
    $args = array(
        'show_option_all'    => '',
        'show_option_none'   => esc_html__( 'All Type', 'ova-hotel' ),
        'option_none_value'  => '',
        'orderby'            => 'ID',
        'order'              => 'ASC',
        'show_count'         => 0,
        'hide_empty'         => 0,
        'child_of'           => 0,
        'exclude'            => $exclude_id,
        'include'            => '',
        'echo'               => 0,
        'selected'           => $selected,
        'hierarchical'       => 1,
        'name'               => 'product_type',
        'id'                 => '',
        'class'              => 'postform '.$required,
        'depth'              => 0,
        'tab_index'          => 0,
        'taxonomy'           => 'type',
        'hide_if_empty'      => false,
        'value_field'        => 'slug',
    );
   
   return wp_dropdown_categories($args);
}



function ovacrs_pagination_theme($ovacrs_query = null) {
    

    echo $ovacrs_query->max_num_pages.'x';

    /** Stop execution if there's only 1 page */
    if($ovacrs_query != null){
        if( $ovacrs_query->max_num_pages <= 1 )
        return; 
    }else if( $wp_query->max_num_pages <= 1 )
        return;



    $paged = get_query_var( 'paged' ) ? absint( get_query_var( 'paged' ) ) : 1;


    

    if($ovacrs_query!=null){
        $max   = intval( $ovacrs_query->max_num_pages );
    }else{
        $max   = intval( $wp_query->max_num_pages );    
    }
    

    /** Add current page to the array */
    if ( $paged >= 1 )
        $links[] = $paged;

    /** Add the pages around the current page to the array */
    if ( $paged >= 3 ) {
        $links[] = $paged - 1;
        $links[] = $paged - 2;
    }

    if ( ( $paged + 2 ) <= $max ) {
        $links[] = $paged + 2;
        $links[] = $paged + 1;
    }


    echo '<nav class="woocommerce-pagination"><ul class="page-numbers">' . "\n";

    /** Previous Post Link */
    if ( get_previous_posts_link() )
        printf( '<li class="prev page-numbers">%s</li>' . "\n", get_previous_posts_link('<i class="arrow_carrot-left"></i>') );

    /** Link to first page, plus ellipses if necessary */
    if ( ! in_array( 1, $links ) ) {
        $class = 1 == $paged ? ' class="current"' : 'page-numbers';

        printf( '<li><a href="%s" %s>%s</a></li>' . "\n",  esc_url( get_pagenum_link( 1 ) ), $class, '1' );

        if ( ! in_array( 2, $links ) )
            echo '<li>...</li>';
    }

    /** Link to current page, plus 2 pages in either direction if necessary */
    sort( $links );
    foreach ( (array) $links as $link ) {
        $class = $paged == $link ? ' class="current"' : '';
        printf( '<li><a href="%s" %s>%s</a></li>' . "\n",  esc_url( get_pagenum_link( $link ) ), $class, $link );
    }

    /** Link to last page, plus ellipses if necessary */
    if ( ! in_array( $max, $links ) ) {
        if ( ! in_array( $max - 1, $links ) )
            echo '<li>...</li>' . "\n";

        $class = $paged == $max ? ' class="current"' : '';
        printf( '<li><a href="%s" %s>%s</a></li>' . "\n",  esc_url( get_pagenum_link( $max ) ), $class, $max );
    }

    /** Next Post Link */
    if ( get_next_posts_link() )
        printf( '<li class="next page-numbers">%s</li>' . "\n", get_next_posts_link('<i class="arrow_carrot-right"></i>') );

    echo '</ul></nav>' . "\n";

}

function get_all_rooms(){
    $args = array(
        'post_type' => 'product',
        'posts_per_page' => '-1',
        'post_status'   => 'publish'
    );
    $rooms = new WP_Query( $args );
    return $rooms;
}

function ovacrs_convert_date_format( $date_time ) {
    $setting_date_format = get_option( 'date_format', 'Y-m-d' );

    if ( $setting_date_format === 'd/m/Y' ) {
        $date_time = str_replace( '/', '-', $date_time );
    }

    return apply_filters( 'ovacrs_ft_convert_date_format', $date_time );
}


if ( ! function_exists( 'ovacrs_create_from_format' ) ){
    function ovacrs_create_from_format( $date ) {
        $date = str_replace( "\\", '', $date );
        $date_formmat   = str_replace( '\\', '', get_option('date_format') );
        $date_conver    = DateTime::createFromFormat( $date_formmat, $date );

        if ( $date_conver ) {
            return $date_conver->format('Y-m-d');
        }

        return $date;
    }
}